aboutsummaryrefslogtreecommitdiffstats
path: root/src/base/UPlatformLinux.pas
diff options
context:
space:
mode:
Diffstat (limited to 'src/base/UPlatformLinux.pas')
-rw-r--r--src/base/UPlatformLinux.pas5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/base/UPlatformLinux.pas b/src/base/UPlatformLinux.pas
index 3227e4f8..9095b192 100644
--- a/src/base/UPlatformLinux.pas
+++ b/src/base/UPlatformLinux.pas
@@ -41,6 +41,9 @@ uses
SysUtils,
ULog;
+const
+ {$I paths.inc}
+
procedure TPlatformLinux.Init;
begin
inherited Init();
@@ -54,7 +57,7 @@ end;
* reside in the directory of the executable.
* - It is global if the game was installed (e.g. to /usr/bin) and
* the resources are in a separate folder (e.g. /usr/share/ultrastardx)
* which name is stored in the INSTALL_DATADIR constant in config-linux.inc.
*
* Sets UseLocalDirs to true if the game is executed locally, false otherwise.
*}
@@ -54,7 +57,7 @@ end;
* - It is global if the game was installed (e.g. to /usr/bin) and
* the resources are in a separate folder (e.g. /usr/share/ultrastardx)
- * which name is stored in the INSTALL_DATADIR constant in config-linux.inc.
+ * which name is stored in the INSTALL_DATADIR constant in paths.inc.
*
* Sets UseLocalDirs to true if the game is executed locally, false otherwise.